@@ -95,14 +95,16 @@ def get_fanin_trans_dict(trans_from_labels,trans_to_labels,subsample_size):
     row_ind, col_ind = linear_sum_assignment(cost_matrix)
     if len(col_ind) != get_num_labels(trans_to_labels):
         raise TranslationError(f"then translation cost matrix is the wrong size for some reason")
-    untranslated = [i for i in range(cost_matrix.shape[1]) if i not in col_ind]
-    unique_untranslated = unique_labels(untranslated)
-    # Now assign the additional, unassigned items
-    cost_matrix2 = np.array([[label_assignment_cost(trans_from_labels,trans_to_labels,l1,l2) for l2 in unique_trans_to_labels if l2 != -1] for l1 in unique_untranslated if l1 != -1])
-    row_ind2, col_ind2 = linear_sum_assignment(cost_matrix2)
     cl = col_ind.tolist()
     trans_dict = {f:cl.index(f) for f in cl}
-    for u,t in zip(untranslated,col_ind2): trans_dict[u]=t
+    while True:
+        untranslated = [i for i in unique_trans_from_labels if i not in trans_dict.keys()]
+        if len(untranslated) == 0: break
+        unique_untranslated = unique_labels(untranslated)
+        # Now assign the additional, unassigned items
+        cost_matrix2 = np.array([[label_assignment_cost(trans_from_labels,trans_to_labels,l1,l2) for l2 in unique_trans_to_labels if l2 != -1] for l1 in unique_untranslated if l1 != -1])
+        row_ind2, col_ind2 = linear_sum_assignment(cost_matrix2)
+        for u,t in zip(untranslated,col_ind2): trans_dict[u]=t
     trans_dict[-1] = -1
     return trans_dict, unique_untranslated
 
